==> ideaIC-163.13906.16-sources.jar: com/intellij/openapi/vcs/changes/actions/ShelveSilentlyAction.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.vcs.changes.actions;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.fileEditor.FileDocumentManager;
import com.intellij.openapi.project.DumbAware;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vcs.VcsDataKeys;
import com.intellij.openapi.vcs.changes.Change;
import com.intellij.openapi.vcs.changes.shelf.ShelveChangesManager;
import com.intellij.util.ObjectUtils;

import java.util.Arrays;

public class ShelveSilentlyAction extends AnAction implements DumbAware {

  @Override
  public void actionPerformed(AnActionEvent e) {
    final Project project = ObjectUtils.assertNotNull(getEventProject(e));
    FileDocumentManager.getInstance().saveAllDocuments();
    Change[] changes = ObjectUtils.assertNotNull(e.getData(VcsDataKeys.CHANGES));
    ShelveChangesManager.getInstance(project).shelveSilentlyUnderProgress(Arrays.asList(changes));
  }

  @Override
  public void update(AnActionEvent e) {
    Change[] changes = e.getData(VcsDataKeys.CHANGES);
    e.getPresentation().setEnabled(getEventProject(e) != null && changes != null && changes.length > 0);
  }
}

==> ideaIC-2018.3.3-sources.jar: com/intellij/openapi/vcs/changes/actions/ShelveSilentlyAction.java <==
/*
 * Copyright 2000-2016 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.openapi.vcs.changes.actions;

import com.intellij.openapi.actionSystem.AnAction;
import com.intellij.openapi.actionSystem.AnActionEvent;
import com.intellij.openapi.fileEditor.FileDocumentManager;
import com.intellij.openapi.project.DumbAware;
import com.intellij.openapi.project.Project;
import com.intellij.openapi.vcs.VcsDataKeys;
import com.intellij.openapi.vcs.changes.Change;
import com.intellij.openapi.vcs.changes.shelf.ShelveChangesManager;
import com.intellij.util.ObjectUtils;
import org.jetbrains.annotations.NotNull;

import java.util.Arrays;

public class ShelveSilentlyAction extends AnAction implements DumbAware {

  @Override
  public void actionPerformed(@NotNull AnActionEvent e) {
    final Project project = ObjectUtils.assertNotNull(getEventProject(e));
    FileDocumentManager.getInstance().saveAllDocuments();
    Change[] changes = ObjectUtils.assertNotNull(e.getData(VcsDataKeys.CHANGES));
    ShelveChangesManager.getInstance(project).shelveSilentlyUnderProgress(Arrays.asList(changes));
  }

  @Override
  public void update(@NotNull AnActionEvent e) {
    Change[] changes = e.getData(VcsDataKeys.CHANGES);
    e.getPresentation().setEnabled(getEventProject(e) != null && changes != null && changes.length > 0);
  }
}
